==> elgg-1.10.1.zip: elgg-1.10.1/mod/bookmarks/languages/de.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Lesezeichen",
	'bookmarks:add' => "Lesezeichen hinzufügen",
	'bookmarks:edit' => "Lesezeichen editieren",
	'bookmarks:owner' => "Lesezeichen von %s",
	'bookmarks:friends' => "Lesezeichen Deiner Freunde",
	'bookmarks:everyone' => "Alle Lesezeichen der Community",
	'bookmarks:this' => "Lesezeichen für diese Seite hinzufügen",
	'bookmarks:this:group' => "Lesezeichen in %s setzen",
	'bookmarks:bookmarklet' => "Bookmarklet zum Browser hinzufügen",
	'bookmarks:bookmarklet:group' => "Gruppen-Bookmarklet zum Browser hinzufügen",
	'bookmarks:inbox' => "Lesezeichen-Inbox",
	'bookmarks:with' => "Teile das Lesezeichen mit",
	'bookmarks:new' => "Ein neues Lesezeichen",
	'bookmarks:address' => "Zieladresse des Lesezeichens",
	'bookmarks:none' => 'Noch keine Lesezeichen vorhanden.',

	'bookmarks:notify:summary' => 'Ein neues Lesezeichen %s wurde erstellt',
	'bookmarks:notify:subject' => 'Neues Lesezeichen: %s',
	'bookmarks:notify:body' =>
'%s hat ein neues Lesezeichen erstellt: %s

Adresse: %s

%s

Schau Dir das neue Lesezeichen an und schreibe einen Kommentar:
%s
',

	'bookmarks:delete:confirm' => "Bist Du sicher, dass Du dieses Lesezeichen löschen willst?",

	'bookmarks:numbertodisplay' => 'Anzahl der anzuzeigenden Lesezeichen-Einträge.',

	'bookmarks:shared' => "Lesezeichen gesetzt",
	'bookmarks:visit' => "Gehe zu dieser Seite",
	'bookmarks:recent' => "Neuesten Lesezeichen",

	'river:create:object:bookmarks' => '%s hat das Lesezeichen %s hinzugefügt.',
	'river:comment:object:bookmarks' => '%s kommentierte das Lesezeichen %s',
	'bookmarks:river:annotate' => 'einen Kommentar zum Lesezeichen',
	'bookmarks:river:item' => 'einen Eintrag',

	'item:object:bookmarks' => 'Lesezeichen',

	'bookmarks:group' => 'Gruppen-Lesezeichen',
	'bookmarks:enablebookmarks' => 'Gruppen-Lesezeichen aktivieren',
	'bookmarks:nogroup' => 'Diese Gruppe hat noch keine Lesezeichen.',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Dieses Widget zeigt Deine neuesten Lesezeichen an.",

	'bookmarks:bookmarklet:description' =>
			"Ein Lesezeichen-Bookmarklet ist eine spezielle Schaltfläche, die Du zur Lesezeichen-Leiste in Deinem Browser hinzufügen kannst. Das Bookmarklet ermöglicht es Dir, für eine Internetseite, die Du zu einem späteren Zeitpunkt noch einmal besuchen willst, ein Lesezeichen zu erstellen und dieses Lesezeichen wahlweise auch mit Deinen Freunden zu teilen. Um das Bookmarklet einzurichten, ziehe die angezeigte Schaltfläche einfach in die Lesezeichen-Leiste Deines Browsers:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Wenn Du den Internet Explorer verwendest, klicke mit der rechten Maustaste auf das Bookmarklet-Icon, wähle 'Zu Favoriten hinzufügen' und dann die Lesezeichen-Leiste.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Du kannst dann ein Lesezeichen für eine Seite erstellen, indem Du auf die Bookmarklet-Schaltfläche in der Lesezeichen-Leiste des Browsers klickst.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Für den Eintrag wurde ein Lesezeichen gesetzt.",
	'bookmarks:delete:success' => "Das Lesezeichen wurde gelöscht.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Das Lesezeichen konnte nicht gespeichert werden. Bitte gebe einen Titel und eine Zieladresse an und versuche es noch einmal.",
	'bookmarks:save:invalid' => "Die Adresse des Lesezeichens ist ungültig und kann nicht gespeichert werden.",
	'bookmarks:delete:failed' => "Das Lesezeichen konnte nicht gelöscht werden. Versuche es bitte noch einmal.",
	'bookmarks:unknown_bookmark' => 'Das ausgewählte Lesezeichen ist nicht auffindbar.',
);

==> elgg-2.3.8.zip: elgg-2.3.8/mod/bookmarks/languages/de.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Lesezeichen",
	'bookmarks:add' => "Lesezeichen hinzufügen",
	'bookmarks:edit' => "Lesezeichen editieren",
	'bookmarks:owner' => "Lesezeichen von %s",
	'bookmarks:friends' => "Lesezeichen Deiner Freunde",
	'bookmarks:everyone' => "Alle Lesezeichen der Community",
	'bookmarks:this' => "Lesezeichen für diese Seite hinzufügen",
	'bookmarks:this:group' => "Lesezeichen in %s setzen",
	'bookmarks:bookmarklet' => "Bookmarklet zum Browser hinzufügen",
	'bookmarks:bookmarklet:group' => "Gruppen-Bookmarklet zum Browser hinzufügen",
	'bookmarks:inbox' => "Lesezeichen-Inbox",
	'bookmarks:address' => "Zieladresse des Lesezeichens",
	'bookmarks:none' => 'Noch keine Lesezeichen vorhanden.',

	'bookmarks:notify:summary' => 'Ein neues Lesezeichen %s wurde erstellt',
	'bookmarks:notify:subject' => 'Neues Lesezeichen: %s',
	'bookmarks:notify:body' =>
'%s hat ein neues Lesezeichen erstellt: %s

Adresse: %s

%s

Schau Dir das neue Lesezeichen an und schreibe einen Kommentar:
%s
',

	'bookmarks:delete:confirm' => "Bist Du sicher, dass Du dieses Lesezeichen löschen willst?",

	'bookmarks:numbertodisplay' => 'Anzahl der anzuzeigenden Lesezeichen-Einträge.',

	'river:create:object:bookmarks' => '%s hat das Lesezeichen %s hinzugefügt.',
	'river:comment:object:bookmarks' => '%s kommentierte das Lesezeichen %s',
	'bookmarks:river:annotate' => 'einen Kommentar zum Lesezeichen',
	'bookmarks:river:item' => 'einen Eintrag',

	'item:object:bookmarks' => 'Lesezeichen',

	'bookmarks:group' => 'Gruppen-Lesezeichen',
	'bookmarks:enablebookmarks' => 'Gruppen-Lesezeichen aktivieren',
	'bookmarks:nogroup' => 'Diese Gruppe hat noch keine Lesezeichen.',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Dieses Widget zeigt Deine neuesten Lesezeichen an.",

	'bookmarks:bookmarklet:description' =>
			"Ein Lesezeichen-Bookmarklet ist eine spezielle Schaltfläche, die Du zur Lesezeichen-Leiste in Deinem Browser hinzufügen kannst. Das Bookmarklet ermöglicht es Dir, für eine Internetseite, die Du zu einem späteren Zeitpunkt noch einmal besuchen willst, ein Lesezeichen zu erstellen. Um das Bookmarklet einzurichten, ziehe die angezeigte Schaltfläche einfach in die Lesezeichen-Leiste Deines Browsers:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Wenn Du den Internet Explorer verwendest, klicke mit der rechten Maustaste auf das Bookmarklet-Icon, wähle 'Zu Favoriten hinzufügen' und dann die Lesezeichen-Leiste.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Du kannst dann ein Lesezeichen für eine Seite erstellen, indem Du auf die Bookmarklet-Schaltfläche in der Lesezeichen-Leiste des Browsers klickst.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Für den Eintrag wurde ein Lesezeichen gesetzt.",
	'bookmarks:delete:success' => "Das Lesezeichen wurde gelöscht.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Das Lesezeichen konnte nicht gespeichert werden. Bitte gebe einen Titel und eine Zieladresse an und versuche es noch einmal.",
	'bookmarks:save:invalid' => "Die Adresse des Lesezeichens ist ungültig und kann nicht gespeichert werden.",
	'bookmarks:delete:failed' => "Das Lesezeichen konnte nicht gelöscht werden. Versuche es bitte noch einmal.",
	'bookmarks:unknown_bookmark' => 'Das ausgewählte Lesezeichen ist nicht auffindbar.',
);
